@@ -3,8 +3,8 @@
 # Win32::ProcFarm::TickCount - method for safely comparing GetTickCount values
 #
 # Author: Toby Everett
-# Revision: 2.12
-# Last Change: Created
+# Revision: 2.13
+# Last Change: Patch to enable operations when 2**32 == 0
 #############################################################################
 # Copyright 1999, 2000, 2001 Toby Everett.  All rights reserved.
 #
@@ -21,13 +21,13 @@ package Win32::ProcFarm::TickCount;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '2.12';
+$VERSION = '2.13';
 
 sub compare {
   my($a, $b) = @_;
 
-  $a = $a % 2**32;
-  $b = $b % 2**32;
+  $a = (int(($a+($a<0 ? 1-2**31 : 0))/2**31) % 2)*2**31 + $a % 2**31;
+  $b = (int(($b+($b<0 ? 1-2**31 : 0))/2**31) % 2)*2**31 + $b % 2**31;
 
   $a == $b and return 0;
   return (abs($a-$b) > 2**31 ? -1 : 1)*($a<=>$b);
